#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from datetime import datetime

from zope.interface import Interface
from zope.schema import Choice, Float, Int, TextLine

from onf_website import _
from pyams_content.shared.common import ISharedContent
from pyams_content.shared.common.interfaces.types import ITypedSharedToolPortalContext, \
    IWfTypedSharedContentPortalContext
from pyams_i18n.schema import I18nHTMLField


RESOURCE_CONTENT_TYPE = 'resource'
RESOURCE_CONTENT_NAME = _("Resource")


class IResourceManager(ITypedSharedToolPortalContext):
    """Resource manager interface"""


class IResourceManagerFactory(Interface):
    """Resource manager factory interface"""


class IWfResource(IWfTypedSharedContentPortalContext):
    """Resource content interface"""


class IWfResourceFactory(Interface):
    """Resource content factory interface"""


class IResource(ISharedContent):
    """Workflow managed resource interface"""


RESOURCE_INFO_ANNOTATIONS_KEY = 'onf_website.resource'


class IResourceInfo(Interface):
    """Resource info interface"""

    editor = TextLine(title=_("Editor"),
                      required=False)

    author = TextLine(title=_("Author"),
                      required=False)

    release_year = Choice(title=_("Release year"),
                          values=range(datetime.today().year, 1970, -1),
                          required=False)

    nb_pages = Int(title=_("Nb pages"),
                   min=0,
                   required=False)

    editor_reference = TextLine(title=_("Editor reference"),
                                required=False)

    isbn_number = TextLine(title=_("ISBN number"),
                           required=False)

    price = Float(title=_("Price"),
                  required=False)

    summary = I18nHTMLField(title=_("Summary"),
                            required=False)

    publisher_words = I18nHTMLField(title=_("Publisher's words"),
                                    required=False)
